@@ -1,11 +1,4 @@
 import pandas as pd
-from dagster_pandas.constraints import (
-    ColumnDTypeFnConstraint,
-    ColumnDTypeInSetConstraint,
-    ConstraintViolationException,
-)
-from dagster_pandas.validation import PandasColumn, validate_constraints
-
 from dagster import (
     AssetMaterialization,
     DagsterInvariantViolationError,
@@ -21,6 +14,12 @@ from dagster import (
 from dagster.config.field_utils import Selector
 from dagster.utils import dict_without_keys
 from dagster.utils.backcompat import canonicalize_backcompat_args, experimental
+from dagster_pandas.constraints import (
+    ColumnDTypeFnConstraint,
+    ColumnDTypeInSetConstraint,
+    ConstraintViolationException,
+)
+from dagster_pandas.validation import PandasColumn, validate_constraints
 
 CONSTRAINT_BLACKLIST = {ColumnDTypeFnConstraint, ColumnDTypeInSetConstraint}
 
@@ -34,6 +33,7 @@ CONSTRAINT_BLACKLIST = {ColumnDTypeFnConstraint, ColumnDTypeInSetConstraint}
             },
             "parquet": {"path": StringSource},
             "table": {"path": StringSource},
+            "pickle": {"path": StringSource},
         },
     )
 )
@@ -48,6 +48,8 @@ def dataframe_materializer(_context, config, pandas_df):
         pandas_df.to_parquet(file_options["path"])
     elif file_type == "table":
         pandas_df.to_csv(file_options["path"], sep="\t", index=False)
+    elif file_type == "pickle":
+        pandas_df.to_pickle(file_options["path"])
     else:
         check.failed("Unsupported file_type {file_type}".format(file_type=file_type))
 
@@ -63,6 +65,7 @@ def dataframe_materializer(_context, config, pandas_df):
             },
             "parquet": {"path": StringSource},
             "table": {"path": StringSource},
+            "pickle": {"path": StringSource},
         },
     )
 )
@@ -76,6 +79,8 @@ def dataframe_loader(_context, config):
         return pd.read_parquet(file_options["path"])
     elif file_type == "table":
         return pd.read_csv(file_options["path"], sep="\t")
+    elif file_type == "pickle":
+        return pd.read_pickle(file_options["path"])
     else:
         raise DagsterInvariantViolationError(
             "Unsupported file_type {file_type}".format(file_type=file_type)
